@@ -3,7 +3,7 @@ import json
 import pandas as pd
 import pandera as pa
 
-from mipdb.exceptions import InvalidDatasetError
+from mipdb.exceptions import InvalidDatasetError, UserInputError
 
 
 class Dataset:
@@ -17,6 +17,7 @@ class Dataset:
         self._data = self._data.astype(object).where(pd.notnull(self._data), None)
         self._verify_dataset_field()
         self._name = self._data["dataset"][0]
+        self._validate_dataset()
 
     @property
     def data(self):
@@ -104,3 +105,7 @@ class Dataset:
                 )
             )
         return checks
+
+    def _validate_dataset(self):
+        if '"' in self.name:
+            raise UserInputError(f'Dataset\'s name: {self.name} contains prohibited character double quotes (")')
