@@ -1,6 +1,7 @@
 import sqlalchemy as sql
 
 from mipdb.database import DataBase
+from mipdb.exceptions import UserInputError
 
 
 class Schema:
@@ -9,6 +10,7 @@ class Schema:
 
     def __init__(self, name) -> None:
         self.name = name
+        self._validate_schema()
         self.schema = sql.MetaData(schema=self.name)
 
     def __repr__(self) -> str:
@@ -19,3 +21,7 @@ class Schema:
 
     def drop(self, db: DataBase):
         db.drop_schema(self.name)
+
+    def _validate_schema(self):
+        if '"' in self.name:
+            raise UserInputError(f'Data model\'s name: {self.name} contains prohibited character double quotes (")')
