@@ -10,6 +10,7 @@ from mipdb.database import DataBase, Connection
 from mipdb.database import METADATA_SCHEMA
 from mipdb.database import METADATA_TABLE
 from mipdb.dataelements import CommonDataElement
+from mipdb.exceptions import UserInputError
 from mipdb.schema import Schema
 
 
@@ -250,10 +251,11 @@ class PrimaryDataTable(Table):
     def from_cdes(
         cls, schema: Schema, cdes: List[CommonDataElement]
     ) -> "PrimaryDataTable":
-        columns = [
-            sql.Column(cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]])
-            for cde in cdes
-        ]
+        columns = []
+        for cde in cdes:
+            if '"' in cde.code:
+                raise UserInputError(f'CDE code: {cde.code} contains prohibited character double quotes (")')
+            columns.append(sql.Column(cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]], quote=True))
         columns.insert(
             0,
             sql.Column(
@@ -275,6 +277,7 @@ class PrimaryDataTable(Table):
             "primary_data", schema.schema, autoload_with=db.get_executor()
         )
         new_table = cls()
+        table.columns = [sql.Column(column.name, quote=True) for column in list(table.columns)]
         new_table.set_table(table)
         return new_table
 
